@@ -1587,6 +1587,53 @@ glade_utils_value_from_string (GType type,
   return NULL;
 }
 
+/**
+ * glade_utils_boolean_from_string:
+ * @string: the string to convert
+ * @value: return location
+ *
+ * Parse a boolean value
+ *
+ * Returns: True if there was an error on the conversion.
+ */
+gboolean
+glade_utils_boolean_from_string (const gchar *string, gboolean *value)
+{
+  if (string)
+    {
+      const gchar *c = string;
+
+      /* Skip white spaces */
+      while (g_ascii_isspace (*c))
+        c++;
+
+      /* We only need the first char */
+      switch (*c)
+        {
+          case '1':
+          case 't':
+          case 'T':
+          case 'y':
+          case 'Y':
+            if (value)
+              *value = TRUE;
+            return FALSE;
+          break;
+
+          case '0':
+          case 'f':
+          case 'F':
+          case 'n':
+          case 'N':
+            if (value)
+              *value = FALSE;
+            return FALSE;
+          break;
+        }
+    }
+
+  return TRUE;
+}
 
 /**
  * glade_utils_string_from_value:
@@ -2023,3 +2070,44 @@ glade_utils_get_pointer (GtkWidget *widget,
   if (y)
     *y = final_y;
 }
+
+/**
+ * _glade_util_file_get_relative_path:
+ * @target: input GFile
+ * @source: input GFile
+ *
+ * Gets the path for @source relative to @target even if @source is not a
+ * descendant of @target.
+ *
+ */
+gchar *
+_glade_util_file_get_relative_path (GFile *target, GFile *source)
+{
+  gchar *relative_path;
+
+  if ((relative_path = g_file_get_relative_path (target, source)) == NULL)
+    {
+      GString *relpath = g_string_new ("");
+
+      g_object_ref (target);
+
+      while (relative_path == NULL)
+        {
+          GFile *old_target = target;
+          target = g_file_get_parent (target);
+
+          relative_path = g_file_get_relative_path (target, source);
+
+          g_string_append (relpath, "..");
+          g_string_append_c (relpath, G_DIR_SEPARATOR);
+
+          g_object_unref (old_target);
+        }
+
+      g_string_append (relpath, relative_path);
+      g_free (relative_path);
+      relative_path = g_string_free (relpath, FALSE);
+    }
+
+  return relative_path;
+}
